@@ -4,7 +4,7 @@ from jinja2 import Template
 from sphinx.application import Sphinx
 
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
 
 def add_gtagjs_context(
@@ -18,7 +18,7 @@ def add_gtagjs_context(
         return
     template = Template(
         """
-        <script async src="https://www.googletagmanager.com/gtag/js"></script>
+        <script async src="https://www.googletagmanager.com/gtag/js?id={{ gtagjs_ids.0 }}"></script>
         <script>
             window.dataLayer = window.dataLayer || [];
             function gtag(){dataLayer.push(arguments);}
